==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/IntegrationServiceEnvironmentAccessEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.IntegrationServiceEnvironmentAccessEndpointType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The integration service environment access endpoint.
 * @property type The access endpoint type.
 */
public data class IntegrationServiceEnvironmentAccessEndpointArgs(
    public val type: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs =
        com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs.builder()
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationServiceEnvironmentAccessEndpointArgs].
 */
@PulumiTagMarker
public class IntegrationServiceEnvironmentAccessEndpointArgsBuilder internal constructor() {
    private var type: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>? = null

    /**
     * @param value The access endpoint type.
     */
    @JvmName("eneihftefarvpunk")
    public suspend
    fun type(`value`: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>) {
        this.type = value
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("jcsvnollaklvfmmy")
    public suspend
    fun type(`value`: Either<String, IntegrationServiceEnvironmentAccessEndpointType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("nrboowuvjlrfdpmn")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationServiceEnvironmentAccessEndpointType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("gkegpmpoawxxivhf")
    public fun type(`value`: IntegrationServiceEnvironmentAccessEndpointType) {
        val toBeMapped = Either.ofRight<String, IntegrationServiceEnvironmentAccessEndpointType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IntegrationServiceEnvironmentAccessEndpointArgs =
        IntegrationServiceEnvironmentAccessEndpointArgs(
            type = type,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/IntegrationServiceEnvironmentAccessEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.IntegrationServiceEnvironmentAccessEndpointType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The integration service environment access endpoint.
 * @property type The access endpoint type.
 */
public data class IntegrationServiceEnvironmentAccessEndpointArgs(
    public val type: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs =
        com.pulumi.azurenative.logic.inputs.IntegrationServiceEnvironmentAccessEndpointArgs.builder()
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationServiceEnvironmentAccessEndpointArgs].
 */
@PulumiTagMarker
public class IntegrationServiceEnvironmentAccessEndpointArgsBuilder internal constructor() {
    private var type: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>? = null

    /**
     * @param value The access endpoint type.
     */
    @JvmName("ptfgukfewooxlehk")
    public suspend
    fun type(`value`: Output<Either<String, IntegrationServiceEnvironmentAccessEndpointType>>) {
        this.type = value
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("dyuyhsjmrurmmqeg")
    public suspend
    fun type(`value`: Either<String, IntegrationServiceEnvironmentAccessEndpointType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("gqablgprqamltfgv")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IntegrationServiceEnvironmentAccessEndpointType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The access endpoint type.
     */
    @JvmName("stwsdccxcpexxrla")
    public fun type(`value`: IntegrationServiceEnvironmentAccessEndpointType) {
        val toBeMapped = Either.ofRight<String, IntegrationServiceEnvironmentAccessEndpointType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IntegrationServiceEnvironmentAccessEndpointArgs =
        IntegrationServiceEnvironmentAccessEndpointArgs(
            type = type,
        )
}
